.. fedcloudclient documentation master file, created by
   sphinx-quickstart on Sun Dec 27 22:25:01 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. raw:: html

    <script type="text/javascript">
    if (String(window.location).indexOf("readthedocs") !== -1) {
        window.alert('The documentation has moved to https://fedcloudclient.fedcloud.eu. I will redirect you to the new location.');
        window.location.replace('https://fedcloudclient.fedcloud.eu');
    }
    </script>

Welcome to FedCloud client's documentation!
===========================================

.. image:: https://zenodo.org/badge/336671726.svg
   :target: https://zenodo.org/badge/latestdoi/336671726

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   quickstart
   install
   usage
   development
   scripts
   fedcloudclient
   FAQ
   cheat



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
